@@ -1,8 +1,32 @@
 #!/usr/bin/python
 # coding: utf-8
 # author: Jérôme Kieffer
-# Benchmark for Azimuthal integration of PyFAI
+#
+#    Project: Fast Azimuthal integration
+#             https://github.com/pyFAI/pyFAI
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+# THE SOFTWARE.
 
+
+"""
+Benchmark for Azimuthal integration of PyFAI
+"""
 from __future__ import print_function, division
 
 import json
@@ -16,8 +40,11 @@ import numpy
 import fabio
 import os.path as op
 import logging
-sys.path.append(op.join(op.dirname(op.dirname(op.abspath(__file__))), "test"))
-import utilstest
+
+# To use use the locally build version of PyFAI, use ../bootstrap.py
+
+import pyFAI
+from pyFAI.test import utilstest
 
 try:
     from rfoo.utils import rconsole
@@ -25,8 +52,6 @@ try:
 except ImportError:
     print("No socket opened for debugging -> please install rfoo")
 
-# We use the locally build version of PyFAI
-pyFAI = utilstest.UtilsTest.pyFAI
 ocl = pyFAI.opencl.ocl
 from pyFAI.gui_utils import pylab, update_fig
 
@@ -51,10 +76,10 @@ class Bench(object):
     FAIL = '\033[91m'
     ENDC = '\033[0m'
     LABELS = {"splitBBox": "CPU_serial",
-          "lut": "CPU_LUT_OpenMP",
-          "lut_ocl": "%s_LUT_OpenCL",
-          "csr": "CPU_CSR_OpenMP",
-          "csr_ocl": "%s_CSR_OpenCL",
+              "lut": "CPU_LUT_OpenMP",
+              "lut_ocl": "%s_LUT_OpenCL",
+              "csr": "CPU_CSR_OpenMP",
+              "csr_ocl": "%s_CSR_OpenCL",
           }
 
     def __init__(self, nbr=10, repeat=1, memprofile=False, unit="2th_deg"):
